aboutsummaryrefslogtreecommitdiffstats
path: root/ui/alert_box.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2017-04-20 11:23:51 -0700
committerGuy Harris <guy@alum.mit.edu>2017-04-20 18:24:20 +0000
commit9e9d284d9157a8b79964015be868f4e8c43274c3 (patch)
treebad43c0cd5b46eb04fd25ed9a5cf6f598d731391 /ui/alert_box.h
parentd09ef614598cf6b714059f39191f09af5701bc93 (diff)
Have separate routines for open-for-reading and open-for-writing errors.
Expand comments while we're at it. Change-Id: I6dcc791eab1c9e323a9572f3d54720d223bdd64b Reviewed-on: https://code.wireshark.org/review/21252 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'ui/alert_box.h')
-rw-r--r--ui/alert_box.h25
1 files changed, 15 insertions, 10 deletions
diff --git a/ui/alert_box.h b/ui/alert_box.h
index ee8d22cdbc..74d3261474 100644
--- a/ui/alert_box.h
+++ b/ui/alert_box.h
@@ -40,18 +40,23 @@ extern void vfailure_alert_box(const char *msg_format, va_list ap);
extern void vwarning_alert_box(const char *msg_format, va_list ap);
/*
* Alert box for a failed attempt to open or create a capture file.
* "err" is assumed to be a UNIX-style errno or a WTAP_ERR_ value;
* "err_info" is assumed to be a string giving further information for
* some WTAP_ERR_ values; "for_writing" is TRUE if the file is being
* opened for writing and FALSE if it's being opened for reading;
* "file_type_subtype" is a WTAP_FILE_TYPE_SUBTYPE_ value for the type
* and subtype of file being opened for writing (it's ignored for
* opening-for-reading errors).
*/
extern void cfile_open_failure_alert_box(const char *filename, int err,
- gchar *err_info, gboolean for_writing,
- int file_type_subtype);
+ gchar *err_info);
+
+/*
+ * Alert box for a failed attempt to open a capture file for writing.
+ * "filename" is the name of the file being opened; "err" is assumed
+ * to be a UNIX-style errno or a WTAP_ERR_ value; "file_type_subtype"
+ * is a WTAP_FILE_TYPE_SUBTYPE_ value for the type and subtype of file
+ * being opened.
+ */
+extern void cfile_dump_open_failure_alert_box(const char *filename, int err,
+ int file_type_subtype);
/*
* Alert box for a failed attempt to read from a capture file.
@@ -40,18 +40,23 @@ extern void vfailure_alert_box(const char *msg_format, va_list ap);
extern void vwarning_alert_box(const char *msg_format, va_list ap);
/*
- * Alert box for a failed attempt to open or create a capture file.
- * "err" is assumed to be a UNIX-style errno or a WTAP_ERR_ value;
- * "err_info" is assumed to be a string giving further information for
- * some WTAP_ERR_ values; "for_writing" is TRUE if the file is being
- * opened for writing and FALSE if it's being opened for reading;
- * "file_type_subtype" is a WTAP_FILE_TYPE_SUBTYPE_ value for the type
- * and subtype of file being opened for writing (it's ignored for
- * opening-for-reading errors).
+ * Alert box for a failed attempt to open a capture file for reading.
+ * "filename" is the name of the file being opened; "err" is assumed
+ * to be a UNIX-style errno or a WTAP_ERR_ value; "err_info" is assumed
+ * to be a string giving further information for some WTAP_ERR_ values..
*/
extern void cfile_open_failure_alert_box(const char *filename, int err,